// CThread Class Definition
// Copyright 2006, Mike Stefanik. All rights reserved.
//
// This material may be freely redistributed and used but may not be
// republished or sold without permission.
//
#ifndef _CTHREAD_CLASS_INC
#define _CTHREAD_CLASS_INC

// Thread creation flags
#define CREATE_SUSPENDED				4

// Thread priorities
#define THREAD_PRIORITY_LOWEST          -2
#define THREAD_PRIORITY_BELOW_NORMAL    -1
#define THREAD_PRIORITY_NORMAL          0
#define THREAD_PRIORITY_HIGHEST         2
#define THREAD_PRIORITY_ABOVE_NORMAL    1
#define THREAD_PRIORITY_TIME_CRITICAL   15
#define THREAD_PRIORITY_IDLE            -15
#define THREAD_PRIORITY_ERROR_RETURN	0x7FFFFFFF

class CThread
{
	// Class constructor and destructor
	declare CThread();
	declare _CThread();

	// Class public methods
	declare Attach(opt unsigned int dwThreadId = 0, opt int bInheritHandle = false), int;
	declare Create(opt unsigned int dwCreationFlags = 0, opt unsigned int nStackSize = 0), int;
	declare Detach(), unsigned int;
	declare Exit(opt unsigned int dwExitCode = 0);
	declare GetExitCode(unsigned int *lpExitCode), int;
	declare GetName(), string;
	declare GetPriority(), int;
	declare IsFinished(), int;
	declare Join(opt unsigned int dwMilliseconds = 0xFFFFFFFF), int;
	declare Resume(), int;
	declare SetName(string strName);
	declare SetPriority(int nPriority), int;
	declare Sleep(opt unsigned int dwMilliseconds = 0);
	declare Suspend(), int;
	declare Terminate(opt unsigned int dwExitCode = 0), int;
	declare WaitForMessage(), int;
	declare Yield();

	// Class virtual methods
	declare virtual ThreadMain(), unsigned int;

	// Class member variables
	unsigned int m_hThread;
	unsigned int m_dwThreadId;
	string m_strThreadName;
}

#endif // _CTHREAD_CLASS_INC
